@@ -177,6 +177,7 @@ static gboolean callerid_widget_expose_event (GtkWidget *widget, GdkEventExpose
 {
 	CallerIDWidget *self = CALLERID_WIDGET (widget);
 	cairo_t *cr;
+	GdkColor color;
 	gint width, height, x, y;
 	gint radius = 5;
 
@@ -184,7 +185,6 @@ static gboolean callerid_widget_expose_event (GtkWidget *widget, GdkEventExpose
 	gdk_cairo_region (cr, event->region);
 	cairo_clip (cr);
 
-	GdkColor color;
 	if (!self->priv->isPressed)
 	{
 		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
@@ -290,7 +290,7 @@ static void callerid_widget_new_callerid_combo (CallerIDWidget *self)
 	if (selIndex >= 0)
 		hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, selIndex);
 
-	g_object_unref (G_OBJECT (store));
+	g_object_unref (store);
 
 	if (gtk_dialog_run (GTK_DIALOG (w)) == GTK_RESPONSE_OK)
 	{
@@ -302,7 +302,7 @@ static void callerid_widget_new_callerid_combo (CallerIDWidget *self)
 			mc_account_call_when_ready (self->priv->ring_acc, (McAccountWhenReadyCb) callerid_widget_on_ready_update, self);
 		}
 	}
-	gtk_widget_destroy (GTK_WIDGET (w));
+	gtk_widget_destroy (w);
 }
 
 static void callerid_widget_on_property_changed (const DBusGProxy *proxy G_GNUC_UNUSED, GHashTable *hash G_GNUC_UNUSED, CallerIDWidget *self)
